<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+14"/>
        <source>About Transmission</source>
        <translation>Transmission について</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Copyright © The Transmission Project</source>
        <translation>Copyright © The Transmission Project</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>高速でお手軽な BitTorrent クライアント</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cc" line="+37"/>
        <source>Client</source>
        <translation>クライアント</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Server</source>
        <translation>サーバー</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>C&amp;redits</source>
        <translation>クレジット(&amp;R)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;License</source>
        <translation>ライセンス(&amp;L)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Credits</source>
        <translation>クレジット</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../Application.cc" line="+332"/>
        <source>&lt;b&gt;Transmission is a file sharing program.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Transmission はファイル共有プログラムです。&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>When you run a torrent, its data will be made available to others by means of upload. Any content you share is your sole responsibility.</source>
        <translation>トレントを利用すると、アップロードを通じてそのデータを他者が入手できるようになります。あなたが共有するコンテンツは、すべてあなた自身の責任です。</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>I &amp;Agree</source>
        <translation>同意する(&amp;A)</translation>
    </message>
    <message numerus="yes">
        <location line="+110"/>
        <source>Torrent(s) Completed</source>
        <translation>
            <numerusform>トレント完了</numerusform>
        </translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Torrent Added</source>
        <translation>追加したトレント</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../DetailsDialog.cc" line="+432"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>混合</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+267"/>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <location line="-210"/>
        <source>Finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>停止</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>%1 (+%2 discarded after failed checksum)</source>
        <translation>%1 (+%2 はチェックサムの失敗により破棄されました)</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Active now</source>
        <translation>稼働中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 ago</source>
        <translation>%1前</translation>
    </message>
    <message numerus="yes">
        <location line="+63"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%Ln ピース @ %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%Ln ピース)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>このトラッカーは非公開 -- DHT と PEX を無効化</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Public torrent</source>
        <translation>公開トレント</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Created by %1</source>
        <translation>作成 %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created on %1</source>
        <translation>作成日 %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created by %1 on %2</source>
        <translation>作成 %1 / 作成日: %2</translation>
    </message>
    <message>
        <location line="+204"/>
        <location line="+47"/>
        <source>Encrypted connection</source>
        <translation>暗号化接続</translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Optimistic unchoke</source>
        <translation>楽観的アンチョーク</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading from this peer</source>
        <translation>このピアからダウンロード中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would download from this peer if they would let us</source>
        <translation>許可があればこのピアからダウンロード</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Uploading to peer</source>
        <translation>ピアにアップロード中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would upload to this peer if they asked</source>
        <translation>要求があればこのピアにアップロード</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>このピアをアンチョークしたがピアへの影響なし</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>私はアンチョークだが大勢への影響なし</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer was discovered through DHT</source>
        <translation>ピアは DHT で発見された</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>ピアをピア交換 (PEX) で発見</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is an incoming connection</source>
        <translation>ピアが接続してきました</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is connected over µTP</source>
        <translation>ピアに µTP を介して接続</translation>
    </message>
    <message numerus="yes">
        <location line="+130"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>分</numerusform>
        </translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Add tracker announce URLs, one per line:</source>
        <translation>トラッカーのアナウンスURL, 1行ごと:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No new URLs found.</source>
        <translation>新規の URL はありませんでした。</translation>
    </message>
    <message>
        <location line="-843"/>
        <source>%1 (100%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data</extracomment>
        <translation>%1 (100%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data, %2 is overall size of torrent data, %3 is percentage (%1/%2*100)</extracomment>
        <translation>%1 / %2 (%3%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded data (both verified and unverified), %2 is overall size of torrent data, %3 is percentage (%1/%2*100), %4 is amount of downloaded but not yet verified data</extracomment>
        <translation>%1 / %2 (%3%), %4 未検証</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>%1 (Ratio: %2)</source>
        <translation>%1 (共有比: %2)</translation>
    </message>
    <message>
        <location line="+273"/>
        <location line="+55"/>
        <source>N/A</source>
        <translation>なし</translation>
    </message>
    <message>
        <location line="+390"/>
        <source>Add URL(s)</source>
        <translation>URL を追加</translation>
    </message>
    <message>
        <location line="+114"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+4"/>
        <source>Use Global Settings</source>
        <translation>全体設定を使用</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Seed regardless of ratio</source>
        <translation>共有比にかかわらずシードする</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>この共有比でシード停止:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Seed regardless of activity</source>
        <translation>稼働にかかわらずシードする</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for:</source>
        <translation>アイドル状態でシード停止:</translation>
    </message>
    <message>
        <location line="+75"/>
        <source>Up</source>
        <translation>上り</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>下り</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>状態</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>アドレス</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>クライアント</translation>
    </message>
    <message>
        <location filename="../DetailsDialog.ui" line="+14"/>
        <source>Torrent Properties</source>
        <translation>トレントのプロパティ</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Information</source>
        <translation>情報</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Activity</source>
        <translation>稼働状況</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Have:</source>
        <translation>所有:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Availability:</source>
        <translation>可用性:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Uploaded:</source>
        <translation>アップロード済み:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Downloaded:</source>
        <translation>ダウンロード済み:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>State:</source>
        <translation>状態:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Running time:</source>
        <translation>実行時間:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Remaining time:</source>
        <translation>残り時間:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Last activity:</source>
        <translation>最終稼働時間;</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Error:</source>
        <translation>エラー:</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Details</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Size:</source>
        <translation>サイズ:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Location:</source>
        <translation>場所:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Edit Trackers</source>
        <translation>トラッカーの編集</translation>
    </message>
    <message>
        <location line="-190"/>
        <source>Hash:</source>
        <translation>ハッシュ:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Privacy:</source>
        <translation>プライバシー:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Origin:</source>
        <translation>起源:</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Added:</source>
        <translation>追加日時:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Peers</source>
        <translation>ピア</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tracker</source>
        <translation>トラッカー</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add Tracker</source>
        <translation>トラッカーを追加</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Remove Trackers</source>
        <translation>トラッカーを削除</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Show &amp;more details</source>
        <translation>詳細表示(&amp;M)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show &amp;backup trackers</source>
        <translation>バックアップトラッカーを表示(&amp;B)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Files</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Honor global &amp;limits</source>
        <translation>速度制限の全体設定を尊重(&amp;L)</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Limit &amp;download speed:</source>
        <translation>ダウンロード速度制限 (&amp;D):</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Limit &amp;upload speed:</source>
        <translation>アップロード速度制限 (&amp;U):</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Torrent &amp;priority:</source>
        <translation>トレントの優先度 (&amp;P):</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Seeding Limits</source>
        <translation>シード制限</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Ratio:</source>
        <translation>共有比(&amp;R):</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Idle:</source>
        <translation>アイドル(&amp;I):</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Peer Connections</source>
        <translation>ピア接続</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Maximum peers:</source>
        <translation>最大ピア数(&amp;M):</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../FileTreeItem.cc" line="+297"/>
        <location filename="../FileTreeView.cc" line="+108"/>
        <location line="+254"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-254"/>
        <location line="+252"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <location line="+253"/>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <source>Mixed</source>
        <translation>混合</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location filename="../FileTreeModel.cc" line="+195"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Progress</source>
        <translation>進行</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Priority</source>
        <translation>優先度</translation>
    </message>
</context>
<context>
    <name>FileTreeView</name>
    <message>
        <location filename="../FileTreeView.cc" line="+244"/>
        <source>Check Selected</source>
        <translation>選択項目をチェック</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uncheck Selected</source>
        <translation>選択項目のチェックを外す</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Only Check Selected</source>
        <translation>選択項目のみチェック</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Priority</source>
        <translation>優先度</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rename…</source>
        <translation>改名…</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../FilterBar.cc" line="+48"/>
        <location line="+145"/>
        <source>All</source>
        <translation>すべて</translation>
    </message>
    <message>
        <location line="-136"/>
        <source>Active</source>
        <translation>稼働中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading</source>
        <translation>ダウンロード中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding</source>
        <translation>シード中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>停止</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Verifying</source>
        <translation>検証中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location line="+140"/>
        <source>Show:</source>
        <translation>表示;</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Search…</source>
        <translation>検索…</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../Formatter.cc" line="+24"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>kB/s</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB/s</source>
        <translation>TB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+25"/>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <location line="-20"/>
        <location line="+10"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../Formatter.h" line="+64"/>
        <location line="+7"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message numerus="yes">
        <location filename="../Formatter.cc" line="+41"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%Ln 日</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-5"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln 時間</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln 分</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%Ln 秒</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FreeSpaceLabel</name>
    <message>
        <location filename="../FreeSpaceLabel.cc" line="+52"/>
        <source>&lt;i&gt;Calculating Free Space…&lt;/i&gt;</source>
        <translation>&lt;i&gt;空き容量の計算中…&lt;/i&gt;</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>%1 free</source>
        <translation>%1 の空き</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../LicenseDialog.ui" line="+14"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+181"/>
        <source>&amp;Torrent</source>
        <translation>トレント(&amp;T)</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Create a new torrent</source>
        <translation>新規トレントの作成</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Properties</source>
        <translation>プロパティ(&amp;P)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>トレントのプロパティを表示</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>トレントのフォルダを開く</translation>
    </message>
    <message>
        <location line="-161"/>
        <source>Queue</source>
        <translation>待ち行列</translation>
    </message>
    <message>
        <location line="-132"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>Statistics</source>
        <translation>統計情報</translation>
    </message>
    <message>
        <location line="+171"/>
        <source>&amp;Open…</source>
        <translation>開く(&amp;O)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>トレントを開く</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;New…</source>
        <translation>新規(&amp;N)</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Open Fold&amp;er</source>
        <translation>フォルダを開く(&amp;E)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Start</source>
        <translation>開始(&amp;S)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>トレントを開始</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>トラッカーからピアを増加(&amp;M)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>トラッカーにピアの増加を要求</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>停止(&amp;P)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>トレントを停止</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Verify Local Data</source>
        <translation>取得データを検証(&amp;V)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>取得データを検証</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Remove</source>
        <translation>除去(&amp;R)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>トレントを除去</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>除去とファイルの削除(&amp;R)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>このトレントとそのファイルも削除</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Start All</source>
        <translation>すべて開始(&amp;S)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>すべて停止(&amp;P)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Select All</source>
        <translation>すべて選択(&amp;S)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Deselect All</source>
        <translation>すべて選択解除(&amp;D)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Preferences</source>
        <translation>設定(&amp;P)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Compact View</source>
        <translation>コンパクト表示(&amp;C)</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>コンパクト表示</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Toolbar</source>
        <translation>ツールバー(&amp;T)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>絞り込みバー(&amp;F)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>ステータスバー(&amp;S)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>稼働順(&amp;A)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>登録日時順(&amp;G)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>残り時間順(&amp;L)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>名前順(&amp;N)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>進行率順(&amp;P)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>共有比順(&amp;O)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>サイズ順(&amp;Z)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>状態順(&amp;E)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>トラッカー順(&amp;R)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>メッセージログ(&amp;L)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>統計(&amp;S)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>オンライン文書(&amp;C)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;About</source>
        <translation>バージョン情報(&amp;A)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>順序を逆に(&amp;V)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>名前(&amp;N)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>トラッカー(&amp;T)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>総比率</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>セッション比率</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>総転送</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>セッション転送</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>メインウィンドウ(&amp;M)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>トレイアイコン(&amp;I)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session…</source>
        <translation>セッションの変更(&amp;C)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set &amp;Location…</source>
        <translation>場所の設定(&amp;L)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;URL…</source>
        <translation>URL を開く(&amp;U)</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>セッションの選択</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>マグネットリンクをコピー(&amp;C)</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Donate</source>
        <translation>寄付する(&amp;D)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>すぐに開始(&amp;N)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>順番待ちを飛ばしてすぐに開始</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Move to &amp;Top</source>
        <translation>先頭へ(&amp;T)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>ひとつ上へ(&amp;U)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move &amp;Down</source>
        <translation>ひとつ下へ(&amp;D)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Bottom</source>
        <translation>最後へ(&amp;B)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>処理待ち順(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cc" line="+468"/>
        <source>Limit Download Speed</source>
        <translation>ダウンロード速度制限</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Unlimited</source>
        <translation>無制限</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+752"/>
        <location line="+9"/>
        <source>Limited at %1</source>
        <translation>%1 に制限</translation>
    </message>
    <message>
        <location line="-706"/>
        <source>Limit Upload Speed</source>
        <translation>アップロード速度制限</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stop Seeding at Ratio</source>
        <translation>この共有比でシード停止</translation>
    </message>
    <message>
        <location line="-40"/>
        <source>Seed Forever</source>
        <translation>常にシードする</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+739"/>
        <source>Stop at Ratio (%1)</source>
        <translation>この共有比で停止 (%1)</translation>
    </message>
    <message>
        <location line="-393"/>
        <source> - %1:%2</source>
        <extracomment>Second (optional) part of main window title &quot;Transmission - host:port&quot; (added when connected to remote session) notice that leading space (before the dash) is included here</extracomment>
        <translation> - %1:%2</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Idle</source>
        <translation>アイドル</translation>
    </message>
    <message>
        <location line="+30"/>
        <location line="+15"/>
        <source>Ratio: %1</source>
        <translation>共有比: %1</translation>
    </message>
    <message>
        <location line="-10"/>
        <location line="+5"/>
        <source>Down: %1, Up: %2</source>
        <translation>下り: %1, 上り: %2</translation>
    </message>
    <message>
        <location line="+424"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>トレントファイル (*.torrent);;すべてのファイル (*.*)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;options dialog</source>
        <translation>オプションのダイアログを表示(&amp;O)</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Open Torrent</source>
        <translation>トレントを開く</translation>
    </message>
    <message>
        <location line="-1003"/>
        <source>Speed Limits</source>
        <translation>速度制限</translation>
    </message>
    <message>
        <location line="+537"/>
        <source>Network Error</source>
        <translation>ネットワークエラー</translation>
    </message>
    <message>
        <location line="+434"/>
        <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>クリックで第二の速度制限を無効化
(%1 下り, %2 上り)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>クリックで第二の速度制限を有効化
 (%1 下り, %2 上り)</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Remove torrent?</source>
        <translation>トレントを除去しますか？</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>このトレントとダウンロード済みファイルを削除しますか？</translation>
    </message>
    <message numerus="yes">
        <location line="-4"/>
        <source>Remove %Ln torrent(s)?</source>
        <translation>
            <numerusform>%Ln トレントを除去しますか？</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-505"/>
        <source>Showing %L1 of %Ln torrent(s)</source>
        <translation>
            <numerusform>%L1 / %Ln トレントを表示中</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+510"/>
        <source>Delete these %Ln torrent(s)&apos; downloaded files?</source>
        <translation>
            <numerusform>これら %Ln トレントのダウンロード済みファイルを削除しますか？</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>一度削除してから転送を続けたい場合、トレントファイルかマグネットリンクが必要です。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>一度削除してから転送を続けたい場合、トレントファイルかマグネットリンクが必要です。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent has not finished downloading.</source>
        <translation>このトレントはダウンロードが完了していません。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>これらのトレントはダウンロードが完了していません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent is connected to peers.</source>
        <translation>このトレントはピアに接続されています。</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>These torrents are connected to peers.</source>
        <translation>これらのトレントはピアに接続されています。</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>これらのトレントの1つがピアに接続されています。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>これらのトレントの一部がピアに接続されています。</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>これらのトレントの1つはダウンロードが完了していません。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>これらのトレントの一部はダウンロードが完了していません。</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>%1 has not responded yet</source>
        <translation>%1 はまだ応答なし</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is responding</source>
        <translation>%1 は応答中</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 last responded %2 ago</source>
        <translation>%1 最後の応答は %2 前</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is not responding</source>
        <translation>%1 は応答していない</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../MakeDialog.ui" line="+17"/>
        <source>New Torrent</source>
        <translation>新規トレント</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="+304"/>
        <source>&lt;i&gt;No source selected&lt;/i&gt;</source>
        <translation>&lt;i&gt;対象が未選択&lt;/i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln ファイル</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln ピース</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 の %2; %3 @ %4</translation>
    </message>
    <message>
        <location filename="../MakeDialog.ui" line="+9"/>
        <source>Files</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Sa&amp;ve to:</source>
        <translation>保存先(&amp;V):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Source f&amp;older:</source>
        <translation>対象フォルダー(&amp;O):</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Source &amp;file:</source>
        <translation>対象ファイル(&amp;F):</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Piece s&amp;ize:</source>
        <translation>ピースの大きさ(&amp;I):</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Properties</source>
        <translation>プロパティ</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Trackers:</source>
        <translation>トラッカー(&amp;T);</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>バックアップ URL は、プライマリ URL の後の行に追加します。
別のプライマリ URL は、空白行の後に追加します。</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Co&amp;mment:</source>
        <translation>コメント(&amp;M):</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Source:</source>
        <translation>入力元(&amp;S):</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Private torrent</source>
        <translation>非公開トレント(&amp;P)</translation>
    </message>
</context>
<context>
    <name>MakeProgressDialog</name>
    <message>
        <location filename="../MakeProgressDialog.ui" line="+14"/>
        <source>New Torrent</source>
        <translation>新規トレント</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="-184"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>作成中「%1」</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>「%1」を作成しました！</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Couldn&apos;t create &quot;%1&quot;: %2 (%3)</source>
        <translation>以下を作成できません「%1」: %2 (%3)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../OptionsDialog.cc" line="+52"/>
        <source>Open Torrent</source>
        <translation>トレントを開く</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Open Torrent from File</source>
        <translation>トレントをファイルから開く</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open Torrent from URL or Magnet Link</source>
        <translation>トレントを URL やマグネットリンクで開く</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+17"/>
        <source>&amp;Source:</source>
        <translation>入力元(&amp;S):</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Destination folder:</source>
        <translation>保存フォルダ(&amp;D):</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="+49"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+35"/>
        <source>&amp;Priority:</source>
        <translation>優先度(&amp;P):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>S&amp;tart when added</source>
        <translation>追加と共に開始(&amp;T)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>.torrent ファイルをごみ箱へ(&amp;V)</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="-40"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>トレントファイル (*.torrent);;すべてのファイル (*.*)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Select Destination</source>
        <translation>保存先の選択</translation>
    </message>
</context>
<context>
    <name>PathButton</name>
    <message>
        <location filename="../PathButton.cc" line="+23"/>
        <location line="+71"/>
        <source>(None)</source>
        <translation>(なし)</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Select Folder</source>
        <translation>フォルダの選択</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Select File</source>
        <translation>ファイルの選択</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../PrefsDialog.ui" line="+1223"/>
        <source>Use &amp;authentication</source>
        <translation>認証を使用(&amp;A)</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Username:</source>
        <translation>ユーザー名(&amp;U):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>パスワード(&amp;W):</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>&amp;Open web client</source>
        <translation>ブラウザで開く(&amp;O)</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Addresses:</source>
        <translation>アドレス:</translation>
    </message>
    <message>
        <location line="-1234"/>
        <source>Speed Limits</source>
        <translation>速度制限</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;通常の速度制限を手動または予定表に従い上書き&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>&amp;Scheduled times:</source>
        <translation>予定時刻(&amp;S):</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>&amp;On days:</source>
        <translation>曜日(&amp;O)</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+382"/>
        <source>Every Day</source>
        <translation>毎日</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>平日</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>週末</translation>
    </message>
    <message>
        <location line="-238"/>
        <source>Sunday</source>
        <translation>日曜日</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Monday</source>
        <translation>月曜日</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tuesday</source>
        <translation>火曜日</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Wednesday</source>
        <translation>水曜日</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Thursday</source>
        <translation>木曜日</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Friday</source>
        <translation>金曜日</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saturday</source>
        <translation>土曜日</translation>
    </message>
    <message>
        <location line="+299"/>
        <source>Port is &lt;b&gt;open&lt;/b&gt;</source>
        <translation>ポートは&lt;b&gt;開いています&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Port is &lt;b&gt;closed&lt;/b&gt;</source>
        <translation>ポートは&lt;b&gt;閉じています&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Testing TCP Port…</source>
        <translation>TCPポートを検査中…</translation>
    </message>
    <message>
        <location line="+154"/>
        <source>Select &quot;Torrent Done Downloading&quot; Script</source>
        <translation>「トレントダウンロード完了」スクリプトの選択</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="+545"/>
        <source>Incoming Peers</source>
        <translation>ピアの待ち受け</translation>
    </message>
    <message>
        <location line="+32"/>
        <location filename="../PrefsDialog.cc" line="+207"/>
        <source>Status unknown</source>
        <translation>状態不明</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>応答接続用ポート(&amp;P):</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>UPnP か NAT-PMP にて自分のルータのポート転送を使用(&amp;F)</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="-255"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>分</numerusform>
        </translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Select &quot;Torrent Done Seeding&quot; Script</source>
        <translation>「トレントシード完了」スクリプトの選択</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source> minute(s) ago</source>
        <extracomment>Spin box suffix, &quot;Download is inactive if data sharing stopped: [ 5 minutes ago ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>分前</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-651"/>
        <source>Automatically add .torrent files &amp;from:</source>
        <translation>ここの .torrent ファイルを自動追加(&amp;F):</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Show the Torrent Options &amp;dialog</source>
        <translation>トレントオプションダイアログを表示(&amp;D)</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>&amp;Start added torrents</source>
        <translation>追加したトレントを開始(&amp;S)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Mo&amp;ve the .torrent file to the trash</source>
        <translation>.torrentファイルをごみ箱に移動(&amp;V)</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Download Queue</source>
        <translation>ダウンロード待ち行列</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Ma&amp;ximum active downloads:</source>
        <translation>最大稼働ダウンロード数(&amp;X):</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Incomplete</source>
        <translation>未完了</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Seeding</source>
        <translation>シード</translation>
    </message>
    <message>
        <location line="+622"/>
        <source>Remote</source>
        <translation>リモート</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="+168"/>
        <source>&lt;i&gt;Blocklist contains %Ln rule(s)&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;ブロックリスト内に %Ln 個の規則があります&lt;/i&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-339"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>Transmission の起動ごとにランダムにポートを変更(&amp;R)</translation>
    </message>
    <message>
        <location line="-274"/>
        <source>Limits</source>
        <translation>制限</translation>
    </message>
    <message>
        <location line="+321"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>トレントごとの最大ピア数(&amp;T):</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>全体での最大ピア数(&amp;O):</translation>
    </message>
    <message>
        <location line="-193"/>
        <source>Blocklist</source>
        <translation>ブロックリスト</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Enable &amp;automatic updates</source>
        <translation>自動更新する(&amp;A)</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-227"/>
        <source>Allow encryption</source>
        <translation>暗号化を許可</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>暗号化を優先</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>暗号化は必須</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-97"/>
        <source>Privacy</source>
        <translation>プライバシー</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>&amp;to</source>
        <translation>から</translation>
    </message>
    <message>
        <location line="+847"/>
        <location line="+9"/>
        <source>Desktop</source>
        <translation>デスクトップ</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Transmission のアイコンを通知領域に表示(&amp;N)</translation>
    </message>
    <message>
        <location line="-265"/>
        <source>Te&amp;st Port</source>
        <translation>ポートのテスト(&amp;S)</translation>
    </message>
    <message>
        <location line="-101"/>
        <source>Enable &amp;blocklist:</source>
        <translation>ブロックリストを使用(&amp;B):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Update</source>
        <translation>更新(&amp;U)</translation>
    </message>
    <message>
        <location line="-66"/>
        <source>&amp;Encryption mode:</source>
        <translation>暗号化の条件(&amp;E):</translation>
    </message>
    <message>
        <location line="+505"/>
        <source>Remote Control</source>
        <translation>リモート接続</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Allow &amp;remote access</source>
        <translation>リモート接続を許可(&amp;R)</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>HTTP &amp;port:</source>
        <translation>HTTP ポート(&amp;P):</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Only allow these IP a&amp;ddresses:</source>
        <translation>以下の IP アドレスのみ許可(&amp;D):</translation>
    </message>
    <message>
        <location line="-1212"/>
        <source>&amp;Upload:</source>
        <translation>アップロード(&amp;U):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Download:</source>
        <translation>ダウンロード(&amp;D):</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Alternative Speed Limits</source>
        <translation>第二の速度制限</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>U&amp;pload:</source>
        <translation>アップロード(&amp;P):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Do&amp;wnload:</source>
        <translation>ダウンロード(&amp;W):</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Reads user clipboard content for torrents</source>
        <translation>クリップボードの内容をトレント用に読み取る</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Detect new torrents from clipboard</source>
        <translation>クリップボードから新規トレントを検出</translation>
    </message>
    <message>
        <location line="+148"/>
        <source>Call scrip&amp;t when downloading is completed:</source>
        <translation>ダウンロード完了時に呼ぶスクリプト(&amp;T):</translation>
    </message>
    <message>
        <location line="+105"/>
        <source>Call scrip&amp;t when seeding is completed:</source>
        <translation>シード完了時に呼ぶスクリプト(&amp;T):</translation>
    </message>
    <message>
        <location line="+342"/>
        <source>µTP is a tool for reducing network congestion.</source>
        <translation>µTP はネットワークの混雑を緩和するツールです。</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable µ&amp;TP for peer connections</source>
        <translation>ピア接続に µTP を使用(&amp;T)</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Default Public Trackers</source>
        <translation>標準の公開トラッカー</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trackers to use on all public torrents.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;p&gt;To add a new primary URL, add it after a blank line.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;すべての公開トレントで使用するトラッカーです。&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;代替URLを追加するときは、プライマリURLの次の行に追加してください。&lt;/p&gt;&lt;p&gt;新しいプライマリURLを追加するときは、空白行を挟んで追加してください。&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Start &amp;minimized in notification area</source>
        <translation>起動時に通知領域に最小化(&amp;M)</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Notification</source>
        <translation>通知</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show a notification when torrents are a&amp;dded</source>
        <translation>トレントが追加されたら通知を表示(&amp;D)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show a notification when torrents &amp;finish</source>
        <translation>トレントが完了したら通知を表示(&amp;F)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Play a &amp;sound when torrents finish</source>
        <translation>トレントが完了したら音を鳴らす(&amp;S)</translation>
    </message>
    <message>
        <location line="-281"/>
        <source>Peer Limits</source>
        <translation>ピア制限</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>PE&amp;X でより多くのピアを探す</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>PEX は、接続中のピア同士でピア一覧を交換するツールです。</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>&amp;DHT でより多くのピアを探す</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>DHT は、トラッカーなしでピアを探すツールです。</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>ローカルピア探索でより多くのピアを探す(&amp;L)</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>LPD は、あなたのローカルネットワーク上のピアを探すツールです。</translation>
    </message>
    <message>
        <location line="-325"/>
        <source>Encryption</source>
        <translation>暗号化</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+75"/>
        <source>Select Incomplete Directory</source>
        <translation>未完了フォルダの選択</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Select Watch Directory</source>
        <translation>監視するフォルダを選択</translation>
    </message>
    <message numerus="yes">
        <location line="-101"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rule(s).&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;b&gt;更新成功!&lt;/b&gt;&lt;p&gt;ブロックリストに %Ln 個の規則があります。&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist…&lt;/p&gt;</source>
        <translation>&lt;b&gt;ブロックリストの更新&lt;/b&gt;&lt;p&gt;新しいブロックリストを取得…&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Select Destination</source>
        <translation>保存先を選択</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-387"/>
        <source>Adding</source>
        <translation>追加</translation>
    </message>
    <message>
        <location line="+147"/>
        <source>Download is i&amp;nactive if data sharing stopped:</source>
        <extracomment>Please keep this phrase as short as possible, it&apos;s currently the longest and influences dialog width</extracomment>
        <translation>データ共有停止でダウンロード未稼働に(&amp;N):</translation>
    </message>
    <message>
        <location line="-156"/>
        <source>Downloading</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <location line="+215"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>未完了のファイル名に .part を付加(&amp;P)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>未完了ファイルの保存先(&amp;I):</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Save to &amp;Location:</source>
        <translation>保存先(&amp;L):</translation>
    </message>
    <message>
        <location line="+282"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>この共有比でシード停止(&amp;R):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Stop seedi&amp;ng if idle for:</source>
        <translation>アイドル状態でシード停止(&amp;N):</translation>
    </message>
    <message>
        <location line="-567"/>
        <source>Transmission Preferences</source>
        <translation>Transmission の設定</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <location line="+735"/>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+116"/>
        <source>Not supported by remote sessions</source>
        <translation>リモートセッションからは変更できません</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../Application.cc" line="-313"/>
        <source>Invalid option</source>
        <translation>無効なオプション</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Start Now</source>
        <translation>すぐ開始</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../RelocateDialog.cc" line="+65"/>
        <source>Select Location</source>
        <translation>保存場所を選択</translation>
    </message>
    <message>
        <location filename="../RelocateDialog.ui" line="+14"/>
        <source>Set Torrent Location</source>
        <translation>トレントの保存場所を設定</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Set Location</source>
        <translation>場所の設定</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>New &amp;location:</source>
        <translation>新しい保存場所(&amp;L):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Move from the current folder</source>
        <translation>現在のフォルダから移動(&amp;M)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Local data is &amp;already there</source>
        <translation>取得データが既にそこにある(&amp;A)</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../Session.cc" line="+505"/>
        <source>Error Renaming Path</source>
        <translation>パスの改名時のエラー</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;p&gt;&lt;b&gt;Unable to rename &quot;%1&quot; as &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please correct the errors and try again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;「%1」を「%2」に改名できません: %3。&lt;/b&gt;&lt;/p&gt;&lt;p&gt;エラーを修正し再度お試しください。&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+528"/>
        <source>Error Adding Torrent</source>
        <translation>トレント追加時のエラー</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>%1 (copy of %2)</source>
        <translation>%1 (%2 のコピー)</translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>Duplicate Torrent(s)</source>
        <translation>
            <numerusform>トレントの重複</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>Unable to add %n duplicate torrent(s)</source>
        <translation>
            <numerusform>%n個の重複したトレントを追加できません</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../SessionDialog.ui" line="+14"/>
        <source>Change Session</source>
        <translation>セッションの変更</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Source</source>
        <translation>接続先</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Start &amp;Local Session</source>
        <translation>このPCでセッションを開始(&amp;L)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>リモートセッションに接続(&amp;R)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Host:</source>
        <translation>ホスト(&amp;H):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Port:</source>
        <translation>ポート(&amp;P):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Authentication required</source>
        <translation>認証あり(&amp;A)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>ユーザー名(&amp;U):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>パスワード(&amp;W):</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../StatsDialog.ui" line="+14"/>
        <source>Statistics</source>
        <translation>統計情報</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Current Session</source>
        <translation>現在のセッション</translation>
    </message>
    <message>
        <location line="+12"/>
        <location line="+96"/>
        <source>Uploaded:</source>
        <translation>アップロード済み:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Downloaded:</source>
        <translation>ダウンロード済み:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Ratio:</source>
        <translation>共有比:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Duration:</source>
        <translation>時間:</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Total</source>
        <translation>合計</translation>
    </message>
    <message numerus="yes">
        <location filename="../StatsDialog.cc" line="+63"/>
        <source>Started %Ln time(s)</source>
        <translation>
            <numerusform>%Ln 回起動</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../Torrent.cc" line="+323"/>
        <source>Verifying local data</source>
        <translation>取得済みのデータを検証中</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Downloading</source>
        <translation>ダウンロード中</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seeding</source>
        <translation>シード中</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Finished</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>中断</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Queued for verification</source>
        <translation>検証の処理待ちに追加</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for download</source>
        <translation>ダウンロードの処理待ちに追加</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for seeding</source>
        <translation>シードの処理待ちに追加</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Tracker gave a warning: %1</source>
        <translation>トラッカーが警告しました: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tracker gave an error: %1</source>
        <translation>トラッカーのエラー: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Error: %1</source>
        <translation>エラー: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../TorrentDelegate.cc" line="+174"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <extracomment>First part of torrent progress string, %1 is the percentage of torrent metadata downloaded</extracomment>
        <translation>マグネット転送 - メタ情報を取得中 (%1%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is how much we&apos;ll have when done, %3 is a percentage of the two</extracomment>
        <translation>%1 / %2 (%3%)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio, %6 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1 / %2 (%3%), アップ済み %4 (共有比: %5 目標: %6)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio</extracomment>
        <translation>%1 / %2 (%3%), アップ済み %4 (共有比: %5)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio, %4 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1, アップ済み %2 (共有比: %3 目標: %4)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio</extracomment>
        <translation>%1, アップ済み %2 (共有比: %3)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source> - %1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation>- 残り %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source> - Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation>- 残り時間不明</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Ratio: %1</source>
        <translation>共有比: %1</translation>
    </message>
    <message numerus="yes">
        <location line="+44"/>
        <source>Downloading from %Ln peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>ダウンロード中, %Ln ピア</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+22"/>
        <source>Seeding to %Ln peer(s)</source>
        <translation>
            <numerusform>%Ln ピアにシード中</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message numerus="yes">
        <location line="-50"/>
        <source>Downloading metadata from %Ln peer(s) (%1% done)</source>
        <translation>
            <numerusform>%Ln ピアからメタ情報をダウンロード中 (%1% 完了)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+15"/>
        <source>Downloading from %1 of %Ln connected peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>ダウンロード中, %Ln 中 %1 の接続ピア</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+8"/>
        <source> and %Ln web seed(s)</source>
        <extracomment>Second (optional) part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;, notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform>と %Ln のウェブシードから</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+13"/>
        <source>Seeding to %1 of %Ln connected peer(s)</source>
        <translation>
            <numerusform>%Ln 中 %1 の接続ピアにシード中</numerusform>
        </translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>取得済みのデータを検証中 (%1% 済み)</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message numerus="yes">
        <location filename="../TrackerDelegate.cc" line="+216"/>
        <source>Got a list of%1 %Ln peer(s)%2 %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>
            <numerusform>%1 %Ln ピア%2の一覧を取得 %3 前</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>ピア一覧の要求が%1タイムアウト%2 %3 前; 再試行</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>エラーを取得 %1&quot;%2&quot;%3 %4 前</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>更新の予定はありません</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>%1 後にピア探索を要求</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for more peers</source>
        <translation>ピア探索を処理待ちに追加</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Asking for peer counts now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>ピア数を要求中… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="-40"/>
        <source>Tracker had%1 %Ln seeder(s)%2</source>
        <extracomment>First part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup</extracomment>
        <translation>
            <numerusform>トラッカーに%1 %Ln のシーダー%2 </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source> and%1 %Ln leecher(s)%2 %3 ago</source>
        <extracomment>Second part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup, %3 is duration; notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform>また %1 %Ln のリーチャー%2 %3 前</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tracker had %1no information%2 on peer counts %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>トラッカーにピア数の%1情報なし%2 %3 前</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>スクレイプのエラー %1&quot;%2&quot;%3 が %4 前に発生</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Asking for more peers now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>ピアの増加を要求… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Asking for peer counts in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>ピア数を問い合わせ %1 後</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for peer counts</source>
        <translation>ピア数確認を処理待ちに追加</translation>
    </message>
</context>
<context>
    <name>TrackersDialog</name>
    <message>
        <location filename="../TrackersDialog.ui" line="+17"/>
        <source>Edit Trackers</source>
        <translation>トラッカーの編集</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Tracker Announce URLs</source>
        <translation>トラッカーのアナウンスURL</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>To add a new primary URL, add it after a blank line.</source>
        <translation>新しいプライマリURLを追加するときは、空白行を挟んで追加してください。</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;代替URLを追加するときは、プライマリURLの次の行に追加してください。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Also see Default Public Trackers in Edit &gt; Preferences &gt; Network</source>
        <translation>編集 &gt; 設定 &gt; ネットワークから、標準の公開トラッカーも参照</translation>
    </message>
</context>
</TS>
